@@ -77,9 +77,10 @@ typedef struct
 
 typedef struct
 {
-	GtkWidget* treeView;
-	GtkTreeStore* treeModel;
-	GtkWidget* scrollWindow;
+	GtkWidget *treeView;
+	GtkWidget *searchbox;
+	GtkTreeStore *treeModel;
+	GtkWidget *scrollWindow;
 } FxTree;
 
 typedef struct
@@ -385,6 +386,7 @@ typedef struct
 	GtkWidget *ctBtn;
 	GtkWidget *etBtn;
 	GtkWidget *alertBtn;
+	GtkWidget *iconBtn;
 	/* personal setting */
 	GtkWidget* image ;
 	GtkWidget* sid_label ;
@@ -466,4 +468,13 @@ typedef struct
 	GtkWidget *iconBtn;
 	GtkWidget *notalert;
 } FxClose;
+
+typedef struct
+{
+	FxMain *fxmain;
+
+	GtkWidget *window;
+	GtkWidget *view;
+}FxSearch;
+
 #endif
