@@ -19,7 +19,9 @@
  ***************************************************************************/
 
 #include "fx_include.h"
-
+#ifdef USE_GSTREAMER
+#include <gst/gst.h>
+#endif
 #include <sys/select.h>
 
 int window_pos_x;
@@ -39,6 +41,22 @@ FxMain* fx_main_new()
 	fxmain->shlist = fx_list_new(NULL);
 	return fxmain;
 }
+
+static gboolean fx_main_move_func(GtkWidget *widget
+		, GdkEventButton *event , gpointer UNUSED(data))
+{
+	int x , y;
+
+	if(event->type == GDK_BUTTON_RELEASE && event->button == 1)
+	{
+		gtk_window_get_position(GTK_WINDOW(widget) , &x , &y);
+	//	window_pos_x = x;
+	//	window_pos_y = y;
+		return TRUE;
+	}
+	return FALSE;
+}
+
 void fx_main_initialize(FxMain* fxmain)
 {
 	int window_width , window_height;
@@ -69,11 +87,15 @@ void fx_main_initialize(FxMain* fxmain)
 	g_signal_connect(G_OBJECT(fxmain->window)
 				  , "window-state-event"
 				  , G_CALLBACK(fx_main_window_state_func)
+				  , fxmain);
+	g_signal_connect(G_OBJECT(fxmain->window)
+				  , "button-release-event"
+				  , G_CALLBACK(fx_main_move_func)
 				  , NULL);
 	gtk_window_set_default_size(GTK_WINDOW(fxmain->window) , WINDOW_WIDTH , WINDOW_HEIGHT);
 	GdkPixbuf* icon = gdk_pixbuf_new_from_file(SKIN_DIR"user_online.png" , NULL);
 	gtk_window_set_icon(GTK_WINDOW(fxmain->window) , icon);
-	fxmain->trayIcon = gtk_status_icon_new_from_file(SKIN_DIR"user_offline.png");
+	fxmain->trayIcon = gtk_status_icon_new_from_file(SKIN_DIR"invisible_big.png");
 	gtk_status_icon_set_tooltip(fxmain->trayIcon , "OpenFetion");
 #ifdef USE_LIBNOTIFY
 	fxmain->notify = notify_notification_new_with_status_icon("welcome"
@@ -139,8 +161,26 @@ GtkWidget* fx_main_create_menu(const char* name
 							 , gpointer data
 							 )
 {
-	GtkWidget* item = gtk_image_menu_item_new_with_label(name);
-	GtkWidget* img = gtk_image_new_from_file(iconpath);
+	GtkWidget *item = gtk_image_menu_item_new_with_label(name);
+	GdkPixbuf *pb = gdk_pixbuf_new_from_file_at_size(iconpath , 16 , 16 , NULL);
+	GtkWidget *img = gtk_image_new_from_pixbuf(pb);
+	g_object_unref(pb);
+	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item) , img);
+	gtk_menu_shell_append(GTK_MENU_SHELL(parent) , item);
+	if(func != NULL)
+		g_signal_connect(item , "activate" , G_CALLBACK(func) , data);
+	return item;
+}
+
+GtkWidget* fx_main_create_menu1(const char* name
+							 , const char *stockid
+							 , GtkWidget* parent
+							 , void (*func)(GtkWidget* item , gpointer data)
+							 , gpointer data
+							 )
+{
+	GtkWidget *item = gtk_image_menu_item_new_with_label(name);
+	GtkWidget *img = gtk_image_new_from_stock(stockid , GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item) , img);
 	gtk_menu_shell_append(GTK_MENU_SHELL(parent) , item);
 	if(func != NULL)
@@ -204,7 +244,7 @@ void fx_main_process_presence(FxMain* fxmain , const char* xml)
 	char *name = NULL;
 	int oldstate , count;
 	Contact *contactlist = NULL;
-	Contact *contact , *contactToDelete;
+	Contact *contact;
 	User* user = fxmain->user;
 	Config *config = user->config;
 	GtkWidget* treeView = fxmain->mainPanel->treeView;
@@ -268,7 +308,7 @@ void fx_main_process_presence(FxMain* fxmain , const char* xml)
 						, contact->impression );
 				pb = gdk_pixbuf_new_from_file_at_size(iconPath , 48 , 48 , NULL);
 				if(pb == NULL){
-					pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.jpg" , 48 , 48 , NULL);
+					pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.png" , 48 , 48 , NULL);
 				}
 				notify_notification_update(fxmain->notify , notifySummary
 						, notifyText , NULL);
@@ -305,7 +345,8 @@ void fx_main_process_presence(FxMain* fxmain , const char* xml)
 	}
 }
 
-static void process_system_message(FxMain *fxmain , const char *sipmsg){
+static void process_system_message(const char *sipmsg)
+{
 	
 	int showonce , type;
 	char *msg , *url;
@@ -348,11 +389,11 @@ void fx_main_process_message(FxMain* fxmain , FetionSip* sip , const char* sipms
 		if(fxchat == NULL)
 		{
 			sid = fetion_sip_get_sid_by_sipuri(msg->sipuri);
-			if(strcmp(sid , "100") == 0)
+			if(strlen(sid) < 8 || strcmp(sid , "10000") == 0)
 			{
 				free(sid);
 				sid = NULL;
-				process_system_message(fxmain , sipmsg);
+				process_system_message(sipmsg);
 				gdk_threads_leave();
 				return;
 			}
@@ -409,7 +450,7 @@ void fx_main_process_message(FxMain* fxmain , FetionSip* sip , const char* sipms
 		sid = NULL;
 		pb = gdk_pixbuf_new_from_file(path , NULL);
 		if(pb == NULL)
-			pb = gdk_pixbuf_new_from_file(SKIN_DIR"user_online.png" , NULL);
+			pb = gdk_pixbuf_new_from_file(SKIN_DIR"online_big.png" , NULL);
 		gtk_status_icon_set_from_pixbuf(GTK_STATUS_ICON(fxmain->trayIcon) , pb);
 		g_object_unref(pb);
 		gtk_status_icon_set_blinking(GTK_STATUS_ICON(fxmain->trayIcon) , TRUE);
@@ -491,9 +532,11 @@ FxChat* fx_main_create_chat_window(FxMain* fxmain , const char* sipuri)
 	if(conv == NULL)
 	{
 		sid = fetion_sip_get_sid_by_sipuri(sipuri);
-		if(strcmp(sid , "100") == 0)
+		if(strlen(sid) < 8 || strcmp(sid , "10000") == 0)
 			return NULL;
+
 		contact = fetion_contact_get_contact_info_by_no(fxmain->user , sid , FETION_NO);
+
 		if(contact == NULL)
 			return NULL;
 		/* replace the sipuri*/
@@ -640,8 +683,6 @@ void fx_main_process_incoming(FxMain* fxmain
 
 void fx_main_process_deregistration(FxMain* fxmain)
 {
-	GtkWidget *dialog;
-
 	DEBUG_FOOTPRINT();
 
 	gdk_threads_enter();
@@ -726,15 +767,16 @@ void fx_main_process_addbuddyapplication(FxMain* fxmain , const char* sipmsg)
 	strcpy(args->sipmsg , sipmsg);
 	g_thread_create(fx_main_process_addbuddyapplication_thread , args , FALSE , NULL);
 }
-void fx_main_destroy(GtkWidget* widget , gpointer data)
+void fx_main_destroy(GtkWidget* UNUSED(widget) , gpointer UNUSED(data))
 {
 	gtk_main_quit();
 }
-gboolean fx_main_delete(GtkWidget* widget , GdkEvent* event , gpointer data)
+gboolean fx_main_delete(GtkWidget *widget , GdkEvent *UNUSED(event) , gpointer data)
 {
 	FxMain *fxmain = (FxMain*)data;
 	FxClose *fxclose;
-	Config *config;
+	Config *config;;
+
 	int ret;
 
 	DEBUG_FOOTPRINT();
@@ -781,32 +823,48 @@ gboolean fx_main_delete(GtkWidget* widget , GdkEvent* event , gpointer data)
 			return FALSE;
 		}
 	}
+	return FALSE;
 }
-gboolean fx_main_window_state_func(GtkWidget* widget , GdkEventWindowState* event , gpointer data)
+gboolean fx_main_window_state_func(GtkWidget *widget
+		, GdkEventWindowState *event , gpointer data)
 {
+	FxMain *fxmain = (FxMain*)data;
+	Config *config = fxmain->user == NULL ? NULL : fxmain->user->config;
 
 	DEBUG_FOOTPRINT();
 
-	if(event->new_window_state == GDK_WINDOW_STATE_ICONIFIED)
-	{
-		gtk_widget_hide(widget);
-		return TRUE;
+	if(config){
+		if(event->new_window_state == GDK_WINDOW_STATE_ICONIFIED){
+			if(config->canIconify == ICON_CAN){
+				gtk_widget_hide(widget);
+				return TRUE;
+			}else{
+				return FALSE;
+			}
+		}
 	}
 	return FALSE;
 }
-void fx_main_tray_activate_func(GtkWidget* widget , gpointer data)
+void fx_main_tray_activate_func(GtkWidget *UNUSED(widget) , gpointer data)
 {
-	FxMain* fxmain = (FxMain*)data;
+	FxMain *fxmain = (FxMain*)data;
+	Config *config = fxmain->user->config;
 
 	DEBUG_FOOTPRINT();
 
 	gtk_window_deiconify(GTK_WINDOW(fxmain->window));
+    if(GTK_WIDGET_VISIBLE(fxmain->window)){
+		if(config->canIconify == ICON_CAN)
+			gtk_widget_hide(fxmain->window);
+	}
+    else{
+        gtk_widget_show(fxmain->window);
+	}
 	gtk_window_move(GTK_WINDOW(fxmain->window) , window_pos_x , window_pos_y);
-	gtk_widget_show(fxmain->window);
 
 }
 
-static void fx_main_mute_clicked(GtkWidget *widget , gpointer data)
+static void fx_main_mute_clicked(GtkWidget *UNUSED(widget) , gpointer data)
 {
 	FxMain *fxmain = (FxMain*)data;
 	User *user = fxmain->user;
@@ -823,7 +881,7 @@ static void fx_main_mute_clicked(GtkWidget *widget , gpointer data)
 
 }
 
-static void fx_main_direct_sms_clicked(GtkWidget *widget , gpointer data)
+static void fx_main_direct_sms_clicked(GtkWidget *UNUSED(widget) , gpointer data)
 {
 	FxMain *fxmain = (FxMain*)data;
 	FxDSMS *fxdsms = fx_dsms_new(fxmain);
@@ -837,7 +895,8 @@ static void fx_main_direct_sms_clicked(GtkWidget *widget , gpointer data)
 	fx_dsms_initialize(fxdsms);
 }
 
-void fx_main_tray_popmenu_func(GtkWidget* widget , guint button , guint activate_time , gpointer data)
+void fx_main_tray_popmenu_func(GtkWidget* UNUSED(widget)
+		, guint button , guint activate_time , gpointer data)
 {
 	FxMain* fxmain = (FxMain*)data;
 	Config *config = NULL;
@@ -874,12 +933,12 @@ void fx_main_tray_popmenu_func(GtkWidget* widget , guint button , guint activate
 	DEBUG_FOOTPRINT();
 
 	menu = gtk_menu_new();
-	fx_main_create_menu("关于OpenFetion" , SKIN_DIR"about.png"
+	fx_main_create_menu1("关于OpenFetion" , GTK_STOCK_ABOUT
 					 , menu , fx_main_about_fetion_clicked , NULL);
-	fx_main_create_menu("查找更新" , SKIN_DIR"about.png"
-					 , menu , fx_main_check_update_clicked , NULL);
-	fx_main_create_menu("关于作者" , SKIN_DIR"about.png"
+	fx_main_create_menu1("关于作者" , GTK_STOCK_HOME
 					 , menu , fx_main_about_author_clicked , NULL);
+	fx_main_create_menu1("查找更新" , GTK_STOCK_HELP
+					 , menu , fx_main_check_update_clicked , NULL);
 	if(fxmain->user != NULL && fxmain->user->loginStatus != -1)
 	{
 		config = fxmain->user->config;
@@ -890,13 +949,13 @@ void fx_main_tray_popmenu_func(GtkWidget* widget , guint button , guint activate
 			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(muteItem) , FALSE);
 		g_signal_connect(muteItem , "activate" , G_CALLBACK(fx_main_mute_clicked) , fxmain);
 		gtk_menu_shell_append(GTK_MENU_SHELL(menu) , muteItem);
-		fx_main_create_menu("信息查询" , SKIN_DIR"find.png"
+		fx_main_create_menu1("信息查询" , GTK_STOCK_FIND
 						 , menu , fx_main_info_lookup_clicked , fxmain);
 		if(fxmain->user->boundToMobile == BOUND_MOBILE_ENABLE){
-			fx_main_create_menu("短信自己" , SKIN_DIR"myselfsms.png"
+			fx_main_create_menu1("短信自己" , GTK_STOCK_FILE
 							 , menu , fx_main_send_to_myself_clicked , fxmain);
 		}
-		statemenu = fx_main_create_menu("修改状态" , SKIN_DIR"user_online.png" , menu , NULL , NULL);
+		statemenu = fx_main_create_menu1("修改状态" , GTK_STOCK_INFO , menu , NULL , NULL);
 		submenu = gtk_menu_new();
 		for(i = 0 ; presence[i].type != -1 ; i++)
 		{
@@ -909,18 +968,18 @@ void fx_main_tray_popmenu_func(GtkWidget* widget , guint button , guint activate
 							 , submenu , fx_main_set_state_clicked , args);
 		}
 		gtk_menu_item_set_submenu(GTK_MENU_ITEM(statemenu) , submenu);
-		fx_main_create_menu("短信群发" , SKIN_DIR"groupsend.png"
+		fx_main_create_menu1("短信群发" , GTK_STOCK_DND_MULTIPLE
 						 , menu , fx_main_send_to_many_clicked , fxmain);
-		fx_main_create_menu("直接短信" , SKIN_DIR"directsms.png"
+		fx_main_create_menu1("直接短信" , GTK_STOCK_DND
 						 , menu , fx_main_direct_sms_clicked , fxmain);
-		fx_main_create_menu("添加好友" , SKIN_DIR"addbuddy.png"
+		fx_main_create_menu1("添加好友" , GTK_STOCK_ADD
 						 , menu , fx_main_add_buddy_clicked , fxmain);
-		fx_main_create_menu("个人设置" , SKIN_DIR"personal.png"
+		fx_main_create_menu1("个人设置" ,  GTK_STOCK_EDIT
 						 , menu , fx_main_personal_setting_clicked , fxmain);
-		fx_main_create_menu("系统设置" , SKIN_DIR"options.png"
+		fx_main_create_menu1("系统设置" , GTK_STOCK_PREFERENCES
 						 , menu , fx_main_system_setting_clicked , fxmain);
 	}
-	fx_main_create_menu("退出Openfetion   " , SKIN_DIR"exit.png"
+	fx_main_create_menu1("退出Openfetion   " , GTK_STOCK_QUIT
 					 , menu , fx_main_destroy , fxmain);
 	gtk_widget_show_all(menu);
 	gtk_menu_popup(GTK_MENU(menu) , NULL , NULL , NULL , NULL 
@@ -1013,7 +1072,7 @@ void* fx_main_listen_thread_func(void* data)
 	}
 	g_thread_exit(0);
 }
-void fx_main_message_func(GtkWidget* widget , gpointer data)
+void fx_main_message_func(GtkWidget *UNUSED(widget) , gpointer data)
 {
 	FxMain *fxmain = (FxMain*)data;
 	FxList *mlist = fxmain->mlist;
@@ -1021,7 +1080,6 @@ void fx_main_message_func(GtkWidget* widget , gpointer data)
 	FxList *tmp = NULL;
 	FxChat *fxchat = NULL;
 	Message *msg = NULL;
-	char *sid = NULL;
 
 	DEBUG_FOOTPRINT();
 
@@ -1069,7 +1127,7 @@ gboolean fx_main_register_func(User* user)
 	if(fetion_user_keep_alive(user) < 0){
 		debug_info("网络连接已断开,请重新登录");
 		gtk_main_quit();
-		return;
+		return FALSE;
 	}
 	return TRUE;
 }
@@ -1088,7 +1146,7 @@ gboolean fx_main_chat_keep_alive_func(TimeOutArgs* args)
 	}
 	return TRUE;
 }
-void fx_main_about_fetion_clicked(GtkWidget* widget , gpointer data)
+void fx_main_about_fetion_clicked(GtkWidget *UNUSED(widget) , gpointer UNUSED(data))
 {
 	GtkWidget *dialog = gtk_about_dialog_new();
 	GdkPixbuf *logo = NULL;
@@ -1100,7 +1158,7 @@ void fx_main_about_fetion_clicked(GtkWidget* widget , gpointer data)
 	gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(dialog), FETION_VERSION); 
 	gtk_about_dialog_set_copyright(GTK_ABOUT_DIALOG(dialog), 
 	"(c) Li Wenpeng");
-	logo = gdk_pixbuf_new_from_file(SKIN_DIR"warning_icon.png" , NULL);
+	logo = gdk_pixbuf_new_from_file(SKIN_DIR"about.png" , NULL);
 	gtk_window_set_icon(GTK_WINDOW(dialog) , logo);
 	gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(dialog), 
 	"OpenFetion 属于非盈利性软件,旨在方便Linux用户使用飞信.");
@@ -1110,38 +1168,40 @@ void fx_main_about_fetion_clicked(GtkWidget* widget , gpointer data)
 	gtk_widget_destroy(dialog);
 }
 
-void fx_main_check_update_clicked(GtkWidget* widget , gpointer data)
+void fx_main_check_update_clicked(GtkWidget* UNUSED(widget) , gpointer UNUSED(data))
 {
 	if(fork() == 0)
 	{
 		execlp("firefox" , "firefox" , "http://basiccoder.com/openfetion" , (char**)NULL);
+		return;
 	}
 }
 
-void fx_main_about_author_clicked(GtkWidget* widget , gpointer data)
+void fx_main_about_author_clicked(GtkWidget* UNUSED(widget) , gpointer UNUSED(data))
 {
 	if(fork() == 0)
 	{
 		execlp("firefox" , "firefox" , "http://www.basiccoder.com" , (char**)NULL);
+		return;
 	}
 }
 
-void fx_main_send_to_myself_clicked(GtkWidget* widget , gpointer data)
+void fx_main_send_to_myself_clicked(GtkWidget *widget , gpointer data)
 {
 	fx_bottom_on_sendtome_clicked(widget , data);
 }
 
-void fx_main_send_to_many_clicked(GtkWidget* widget , gpointer data)
+void fx_main_send_to_many_clicked(GtkWidget *widget , gpointer data)
 {
 	fx_bottom_on_sendtomany_clicked(widget , data);
 }
 
-void fx_main_personal_setting_clicked(GtkWidget* widget , gpointer data)
+void fx_main_personal_setting_clicked(GtkWidget *widget , gpointer data)
 {
 	fx_bottom_on_setting_clicked(widget , data);
 }
 
-void fx_main_system_setting_clicked(GtkWidget* widget , gpointer data)
+void fx_main_system_setting_clicked(GtkWidget *UNUSED(widget) , gpointer data)
 {
 	FxMain *fxmain = (FxMain*)data;
 	FxSet *fxset = fx_set_new(fxmain);
@@ -1152,22 +1212,22 @@ void fx_main_system_setting_clicked(GtkWidget* widget , gpointer data)
 	gtk_widget_destroy(fxset->dialog);
 }
 
-void fx_main_set_state_clicked(GtkWidget* widget , gpointer data)
+void fx_main_set_state_clicked(GtkWidget *widget , gpointer data)
 {
 	fx_head_change_state_func(widget , data);
 }
 
-void fx_main_add_buddy_clicked(GtkWidget* widget , gpointer data)
+void fx_main_add_buddy_clicked(GtkWidget *widget , gpointer data)
 {
 	fx_bottom_on_addfriend_clicked(widget , data);
 }
 
-void fx_main_info_lookup_clicked(GtkWidget* widget , gpointer data)
+void fx_main_info_lookup_clicked(GtkWidget *widget , gpointer data)
 {
 	fx_bottom_on_lookup_clicked(widget , data);
 }
 
-FetionSip* fx_list_find_sip_by_sipuri(FxList* fxlist , const char* sipuri)
+FetionSip* fx_list_find_sip_by_sipuri(FxList *fxlist , const char *sipuri)
 {
 	FxList *cur;
 	FetionSip *sip;
@@ -1187,7 +1247,7 @@ FetionSip* fx_list_find_sip_by_sipuri(FxList* fxlist , const char* sipuri)
 	}
 	return NULL;
 }
-void fx_list_remove_sip_by_sipuri(FxList* fxlist , const char* sipuri)
+void fx_list_remove_sip_by_sipuri(FxList *fxlist , const char *sipuri)
 {
 	FxList *cur;
 	FetionSip *sip;
@@ -1214,7 +1274,7 @@ void fx_list_remove_sip_by_sipuri(FxList* fxlist , const char* sipuri)
 	}
 }
 
-FxChat* fx_list_find_chat_by_sipuri(FxList* fxlist , const char* sipuri)
+FxChat* fx_list_find_chat_by_sipuri(FxList *fxlist , const char *sipuri)
 {
 	FxChat *fxchat;
 	FxList *cur;
